@@ -77,8 +77,9 @@ def create_app(handler):
     @app.route('/offer/<hash>')
     def offer(hash):
         client_host = request.remote_addr
+        client_port = request.environ.get('REMOTE_PORT') or 0
         try:
-            offer = handler.handle_get_offer(hash, client_host)
+            offer = handler.handle_get_offer(hash, client_host, client_port)
         except NotFoundError:
             return "Not found", 404
         return jsonify({
